# prueba_ifsUW
_Provides a 2D interactive visualisation of the spaxels and spectra of a 3D cube_
### Instalación
_For install the package of prueba_ifsUW:_
_pip install prueba_ifsUW_
_For show the window of prueba_ifsUW, in any terminal of python run the next code:_
_from prueba_ifsUW import * _
_x = prueba_ifsUW()_
_The program accept FITS files with extensions: .fits .fits.gz_
_The fits files should have projection of RA and DEC or grades_